==> ssp_api-1.2.1.14-sources.jar: com/cloud/hisavana/sdk/data/bean/request/DeviceDTO.java <==
package com.cloud.hisavana.sdk.data.bean.request;
/**
 * @author: wenjing.luo
 * @date: 2021/8/5
 * ==================================
 * Copyright (c) 2021 TRANSSION.Co.Ltd.
 * All rights reserved.
 *
 * 广告请求数据bean
 */
public class DeviceDTO {
    private int type;
    private String brand;
    private String model;
    private String maker;
    private int osType;
    private String osVersion;
    private String language;
    private String networkConnectionType;
    private String operatorType;
    private String ipAddress;
    private String gaidNewAES;//新加密算法

    private String mac;
    private String imsi;
    private String imeiSha1;
    private String imeiMd5;
    private String androidIdSha1;
    private String androidIdMd5;
    private int screenWidth;
    private int screenHeight;
    private int screenDensity;

    public int getType() {
        return type;
    }

    public void setType(int type) {
        this.type = type;
    }

    public String getBrand() {
        return brand;
    }

    public void setBrand(String brand) {
        this.brand = brand;
    }

    public String getModel() {
        return model;
    }

    public void setModel(String model) {
        this.model = model;
    }

    public String getMaker() {
        return maker;
    }

    public void setMaker(String maker) {
        this.maker = maker;
    }

    public int getOsType() {
        return osType;
    }

    public void setOsType(int osType) {
        this.osType = osType;
    }

    public String getOsVersion() {
        return osVersion;
    }

    public void setOsVersion(String osVersion) {
        this.osVersion = osVersion;
    }

    public String getLanguage() {
        return language;
    }

    public void setLanguage(String language) {
        this.language = language;
    }

    public String getNetworkConnectionType() {
        return networkConnectionType;
    }

    public void setNetworkConnectionType(String networkConnectionType) {
        this.networkConnectionType = networkConnectionType;
    }

    public String getOperatorType() {
        return operatorType;
    }

    public void setOperatorType(String operatorType) {
        this.operatorType = operatorType;
    }

    public String getIpAddress() {
        return ipAddress;
    }

    public void setIpAddress(String ipAddress) {
        this.ipAddress = ipAddress;
    }

    public String getGaidNewAES() {
        return gaidNewAES;
    }

    public void setGaidNewAES(String gaidNewAES) {
        this.gaidNewAES = gaidNewAES;
    }

    public String getMac() {
        return mac;
    }

    public void setMac(String mac) {
        this.mac = mac;
    }

    public String getImsi() {
        return imsi;
    }

    public void setImsi(String imsi) {
        this.imsi = imsi;
    }

    public String getImeiSha1() {
        return imeiSha1;
    }

    public void setImeiSha1(String imeiSha1) {
        this.imeiSha1 = imeiSha1;
    }

    public String getImeiMd5() {
        return imeiMd5;
    }

    public void setImeiMd5(String imeiMd5) {
        this.imeiMd5 = imeiMd5;
    }

    public String getAndroidIdSha1() {
        return androidIdSha1;
    }

    public void setAndroidIdSha1(String androidIdSha1) {
        this.androidIdSha1 = androidIdSha1;
    }

    public String getAndroidIdMd5() {
        return androidIdMd5;
    }

    public void setAndroidIdMd5(String androidIdMd5) {
        this.androidIdMd5 = androidIdMd5;
    }

    public int getScreenWidth() {
        return screenWidth;
    }

    public void setScreenWidth(int screenWidth) {
        this.screenWidth = screenWidth;
    }

    public int getScreenHeight() {
        return screenHeight;
    }

    public void setScreenHeight(int screenHeight) {
        this.screenHeight = screenHeight;
    }

    public int getScreenDensity() {
        return screenDensity;
    }

    public void setScreenDensity(int screenDensity) {
        this.screenDensity = screenDensity;
    }
}

==> ssp_api-1.2.1.21-sources.jar: com/cloud/hisavana/sdk/data/bean/request/DeviceDTO.java <==
package com.cloud.hisavana.sdk.data.bean.request;
/**
 * @author: wenjing.luo
 * @date: 2021/8/5
 * ==================================
 * Copyright (c) 2021 TRANSSION.Co.Ltd.
 * All rights reserved.
 *
 * 广告请求数据bean
 */
public class DeviceDTO {
    private int type;
    private String brand;
    private String model;
    private String maker;
    private int osType;
    private String osVersion;
    private String language;
    private String networkConnectionType;
    private String operatorType;
    private String ipAddress;

    @Deprecated
    private String gaid; // 不上传了
    private String gaidAES; // 加密上传

    private String mac;
    private String imsi;
    private String imeiSha1;
    private String imeiMd5;
    private String androidIdSha1;
    private String androidIdMd5;
    private int screenWidth;
    private int screenHeight;
    private int screenDensity;

    public int getType() {
        return type;
    }

    public void setType(int type) {
        this.type = type;
    }

    public String getBrand() {
        return brand;
    }

    public void setBrand(String brand) {
        this.brand = brand;
    }

    public String getModel() {
        return model;
    }

    public void setModel(String model) {
        this.model = model;
    }

    public String getMaker() {
        return maker;
    }

    public void setMaker(String maker) {
        this.maker = maker;
    }

    public int getOsType() {
        return osType;
    }

    public void setOsType(int osType) {
        this.osType = osType;
    }

    public String getOsVersion() {
        return osVersion;
    }

    public void setOsVersion(String osVersion) {
        this.osVersion = osVersion;
    }

    public String getLanguage() {
        return language;
    }

    public void setLanguage(String language) {
        this.language = language;
    }

    public String getNetworkConnectionType() {
        return networkConnectionType;
    }

    public void setNetworkConnectionType(String networkConnectionType) {
        this.networkConnectionType = networkConnectionType;
    }

    public String getOperatorType() {
        return operatorType;
    }

    public void setOperatorType(String operatorType) {
        this.operatorType = operatorType;
    }

    public String getIpAddress() {
        return ipAddress;
    }

    public void setIpAddress(String ipAddress) {
        this.ipAddress = ipAddress;
    }

    @Deprecated
    public String getGaid() {
        return gaid;
    }

    @Deprecated
    public void setGaid(String gaid) {
        this.gaid = gaid;
    }

    public String getGaidAES() {
        return gaidAES;
    }

    public void setGaidAES(String gaidAES) {
        this.gaidAES = gaidAES;
    }

    public String getMac() {
        return mac;
    }

    public void setMac(String mac) {
        this.mac = mac;
    }

    public String getImsi() {
        return imsi;
    }

    public void setImsi(String imsi) {
        this.imsi = imsi;
    }

    public String getImeiSha1() {
        return imeiSha1;
    }

    public void setImeiSha1(String imeiSha1) {
        this.imeiSha1 = imeiSha1;
    }

    public String getImeiMd5() {
        return imeiMd5;
    }

    public void setImeiMd5(String imeiMd5) {
        this.imeiMd5 = imeiMd5;
    }

    public String getAndroidIdSha1() {
        return androidIdSha1;
    }

    public void setAndroidIdSha1(String androidIdSha1) {
        this.androidIdSha1 = androidIdSha1;
    }

    public String getAndroidIdMd5() {
        return androidIdMd5;
    }

    public void setAndroidIdMd5(String androidIdMd5) {
        this.androidIdMd5 = androidIdMd5;
    }

    public int getScreenWidth() {
        return screenWidth;
    }

    public void setScreenWidth(int screenWidth) {
        this.screenWidth = screenWidth;
    }

    public int getScreenHeight() {
        return screenHeight;
    }

    public void setScreenHeight(int screenHeight) {
        this.screenHeight = screenHeight;
    }

    public int getScreenDensity() {
        return screenDensity;
    }

    public void setScreenDensity(int screenDensity) {
        this.screenDensity = screenDensity;
    }
}
